Coverage for modules/box__default/appadmin/templates/appadmin/blocks/sidebar.html: 100%

# Coverage for modules/box__default/appadmin/templates/appadmin/blocks/sidebar.html : 100%

## 3 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1{{

2 sidebar_item(

3'Home',

4 icon='fas fa-user-lock',

5 url=url_for('appadmin.user_list')

6)

7}}

8

9

10{{

11 sidebar_item(

12'Add',

13 icon='fas fa-plus-circle',

14 url=url_for('appadmin.user_add')

15)

16}}

17

18

19{{

20 sidebar_item(

21'Roles',

22 icon='fa fa-shield-alt',

23 url=url_for('appadmin.roles')

24)

25}}